@@ -1,32 +1,33 @@
-# 
+#
 # This file is part of Curses-Toolkit
-# 
-# This software is copyright (c) 2008 by Damien "dams" Krotkine.
-# 
+#
+# This software is copyright (c) 2010 by Damien "dams" Krotkine.
+#
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
-# 
+#
 use warnings;
 use strict;
 
 package Curses::Toolkit::Object;
-our $VERSION = '0.100680';
-
-
-
+BEGIN {
+  $Curses::Toolkit::Object::VERSION = '0.200';
+}
 # ABSTRACT: base class for objects
 
+use Moose;
 
-sub new {
+sub BUILDARGS {
     my ($class) = shift;
-
     # TODO : use Exception;
     $class eq __PACKAGE__ and die "abstract class";
 }
 
+no Moose;
+__PACKAGE__->meta->make_immutable;
+
 1;
 
-__END__
 
 =pod
 
@@ -36,27 +37,25 @@ Curses::Toolkit::Object - base class for objects
 
 =head1 VERSION
 
-version 0.100680
+version 0.200
 
 =head1 DESCRIPTION
 
-Base class for objects
-
-=head1 CONSTRUCTOR
-
-None, this is an abstract class
-
-
+Base class for objects. This class cannot be instanciated.
 
 =head1 AUTHOR
 
-  Damien "dams" Krotkine
+Damien "dams" Krotkine
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2008 by Damien "dams" Krotkine.
+This software is copyright (c) 2010 by Damien "dams" Krotkine.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
\ No newline at end of file
+=cut
+
+
+__END__
+
