@@ -1,18 +1,18 @@
-# 
+#
 # This file is part of Curses-Toolkit
-# 
-# This software is copyright (c) 2008 by Damien "dams" Krotkine.
-# 
+#
+# This software is copyright (c) 2010 by Damien "dams" Krotkine.
+#
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
-# 
+#
 use warnings;
 use strict;
 
 package Curses::Toolkit::Signal::Content::Changed;
-our $VERSION = '0.100680';
-
-
+BEGIN {
+  $Curses::Toolkit::Signal::Content::Changed::VERSION = '0.200';
+}
 
 use parent qw(Curses::Toolkit::Signal::Content);
 
@@ -48,34 +48,36 @@ sub generate_listener {
 1;
 
 __END__
-
 =pod
 
-=head1 VERSION
-
-version 0.100680
-
 =head1 NAME
 
 Curses::Toolkit::Signal::Content::Changed
 
+=head1 VERSION
+
+version 0.200
+
 =head1 DESCRIPTION
 
 Signal triggered when the content of a widget changes
 
+=head1 NAME
+
+Curses::Toolkit::Signal::Content::Changed
+
 =head1 CONSTRUCTOR
 
-
-
 =head1 AUTHOR
 
-  Damien "dams" Krotkine
+Damien "dams" Krotkine
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2008 by Damien "dams" Krotkine.
+This software is copyright (c) 2010 by Damien "dams" Krotkine.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
\ No newline at end of file
+=cut
+
