@@ -1,18 +1,18 @@
-# 
+#
 # This file is part of Curses-Toolkit
-# 
-# This software is copyright (c) 2008 by Damien "dams" Krotkine.
-# 
+#
+# This software is copyright (c) 2010 by Damien "dams" Krotkine.
+#
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
-# 
+#
 use warnings;
 use strict;
 
 package Curses::Toolkit::Theme::Default;
-our $VERSION = '0.100680';
-
-
+BEGIN {
+  $Curses::Toolkit::Theme::Default::VERSION = '0.200';
+}
 
 # ABSTRACT: default widget theme
 
@@ -69,12 +69,23 @@ sub _get_default_properties {
             # inherited from Border
             border_width => 0,
 
-            left_enclosing  => '[',
-            right_enclosing => ']',
-            default_width   => 12,
+            start_enclosing  => '[',
+            end_enclosing => ']',
+            default_length   => 12,
             char_done       => '|',
             char_left       => '-',
         },
+        'Curses::Toolkit::Widget::VProgressBar' => {
+
+            # inherited from Border
+            border_width => 0,
+
+            start_enclosing => '-',
+            end_enclosing   => '-',
+            default_length  => 12,
+            char_done       => '#',
+            char_left       => '|',
+        },
     );
     return $default{$class_name} || {};
 }
@@ -92,6 +103,10 @@ sub STRING_NORMAL  { }
 sub STRING_FOCUSED { shift->_attron(A_REVERSE) }
 sub STRING_CLICKED { shift->_attron(A_BOLD) }
 
+sub VSTRING_NORMAL  { }
+sub VSTRING_FOCUSED { shift->_attron(A_REVERSE) }
+sub VSTRING_CLICKED { shift->_attron(A_BOLD) }
+
 sub TITLE_NORMAL  { }
 sub TITLE_FOCUSED { shift->_attron(A_REVERSE) }
 sub TITLE_CLICKED { shift->_attron(A_BOLD) }
@@ -122,7 +137,7 @@ sub draw_hline {
     $y1 >= 0 or return;
     my $c = $self->restrict_to_shape( x1 => $x1, y1 => $y1, width => $width, height => 1 )
         or return;
-    $self->curses($attr)->hline( $c->y1(), $c->x1(), HLINE(), $c->width() );
+    $self->curses($attr)->hline( $c->get_y1(), $c->get_x1(), HLINE(), $c->width() );
     return $self;
 }
 
@@ -132,7 +147,7 @@ sub draw_vline {
     $x1 >= 0 or return;
     my $c = $self->restrict_to_shape( x1 => $x1, y1 => $y1, width => 1, height => $height )
         or return;
-    $self->curses($attr)->vline( $c->y1(), $c->x1(), VLINE(), $c->height() );
+    $self->curses($attr)->vline( $c->get_y1(), $c->get_x1(), VLINE(), $c->height() );
     return $self;
 }
 
@@ -178,12 +193,34 @@ sub draw_string {
 
     my $c = $self->restrict_to_shape( x1 => $x1, y1 => $y1, width => $text->stripped_length(), height => 1 ) or return;
 
-    my $start = $c->x1() - $x1;
-    my $end   = $c->x1() - $x1 + $c->width();
+    my $start = $c->get_x1() - $x1;
+    my $end   = $c->get_x1() - $x1 + $c->width();
     my $width = $end - $start;
     $text = $text->substring( $start, $width );
     $text->stripped_length() or return;
-    $self->_addstr_with_tags( $attr, $c->x1(), $c->y1(), $text );
+    $self->_addstr_with_tags( $attr, $c->get_x1(), $c->get_y1(), $text );
+    return $self;
+}
+
+sub draw_vstring {
+    my ( $self, $x1, $y1, $text, $attr ) = @_;
+    $self->get_widget->is_visible() or return;
+
+    use Curses::Toolkit::Object::MarkupString;
+    ref $text
+        or $text = Curses::Toolkit::Object::MarkupString->new($text);
+
+    my $c = $self->restrict_to_shape( x1 => $x1, y1 => $y1, width => 1, height => $text->stripped_length() ) or return;
+
+    my $start  = $c->get_y1() - $y1;
+    my $end    = $c->get_y1() - $y1 + $c->height();
+    my $height = $end - $start;
+    $text = $text->substring( $start, $height );
+    $text->stripped_length() or return;
+    foreach my $y (0..$height-1) {
+        my $char = $text->substring( $y, 1 );
+        $self->_addstr_with_tags( $attr, $c->get_x1(), $c->get_y1() + $y, $char );
+    }
     return $self;
 }
 
@@ -192,11 +229,11 @@ sub draw_title {
     $self->get_widget->is_visible() or return;
     my $c = $self->restrict_to_shape( x1 => $x1, y1 => $y1, width => length($text), height => 1 ) or return;
 
-    $c->x1() - $x1 < length $text
+    $c->get_x1() - $x1 < length $text
         or return;
-    $text = substr( $text, $c->x1() - $x1, $c->width() );
+    $text = substr( $text, $c->get_x1() - $x1, $c->width() );
     defined $text && length $text or return;
-    $self->curses($attr)->addstr( $c->y1(), $c->x1(), $text );
+    $self->curses($attr)->addstr( $c->get_y1(), $c->get_x1(), $text );
     return $self;
 }
 
@@ -214,11 +251,11 @@ sub draw_blank {
     my ($c) = validate_pos( @_, { isa => 'Curses::Toolkit::Object::Coordinates' } );
     $c = $self->restrict_to_shape($c)
         or return;
-    my $l = $c->x2() - $c->x1();
+    my $l = $c->get_x2() - $c->get_x1();
     $l > 0 or return $self;
     my $str = ' ' x $l;
-    foreach my $y ( $c->y1() .. $c->y2() - 1 ) {
-        $self->curses->addstr( $y, $c->x1(), $str );
+    foreach my $y ( $c->get_y1() .. $c->get_y2() - 1 ) {
+        $self->curses->addstr( $y, $c->get_x1(), $str );
     }
     return $self;
 }
@@ -226,7 +263,6 @@ sub draw_blank {
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -235,7 +271,7 @@ Curses::Toolkit::Theme::Default - default widget theme
 
 =head1 VERSION
 
-version 0.100680
+version 0.200
 
 =head1 DESCRIPTION
 
@@ -248,17 +284,16 @@ This theme is used by default when rendering widgets.
   input : a Curses::Toolkit::Widget
   output : a Curses::Toolkit::Theme::Default
 
-
-
 =head1 AUTHOR
 
-  Damien "dams" Krotkine
+Damien "dams" Krotkine
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2008 by Damien "dams" Krotkine.
+This software is copyright (c) 2010 by Damien "dams" Krotkine.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
\ No newline at end of file
+=cut
+
