@@ -1,18 +1,18 @@
-# 
+#
 # This file is part of Curses-Toolkit
-# 
-# This software is copyright (c) 2008 by Damien "dams" Krotkine.
-# 
+#
+# This software is copyright (c) 2010 by Damien "dams" Krotkine.
+#
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
-# 
+#
 use warnings;
 use strict;
 
 package Curses::Toolkit::Theme::Default::Color::Yellow;
-our $VERSION = '0.100680';
-
-
+BEGIN {
+  $Curses::Toolkit::Theme::Default::Color::Yellow::VERSION = '0.200';
+}
 
 # ABSTRACT: default widget theme with color
 
@@ -49,6 +49,10 @@ sub STRING_NORMAL  { shift->_set_colors( 'white', 'black' ) }
 sub STRING_FOCUSED { shift->_set_colors( 'white', 'black' )->_attron(A_REVERSE) }
 sub STRING_CLICKED { shift->_set_colors( 'white', 'black' )->_attron(A_BOLD) }
 
+sub VSTRING_NORMAL  { shift->_set_colors( 'white', 'black' ) }
+sub VSTRING_FOCUSED { shift->_set_colors( 'white', 'black' )->_attron(A_REVERSE) }
+sub VSTRING_CLICKED { shift->_set_colors( 'white', 'black' )->_attron(A_BOLD) }
+
 sub TITLE_NORMAL  { shift->_set_colors( 'yellow', 'black' ) }
 sub TITLE_FOCUSED { shift->_set_colors( 'red',    'black' )->_attron(A_BOLD) }
 sub TITLE_CLICKED { shift->_set_colors( 'yellow', 'black' )->_attron(A_REVERSE) }
@@ -61,7 +65,6 @@ sub RESIZE_CLICKED { shift->_set_colors( 'yellow', 'black' )->_attron(A_REVERSE)
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -70,7 +73,7 @@ Curses::Toolkit::Theme::Default::Color::Yellow - default widget theme with color
 
 =head1 VERSION
 
-version 0.100680
+version 0.200
 
 =head1 DESCRIPTION
 
@@ -83,17 +86,16 @@ This theme is used by default when rendering widgets, if color is available.
   input : a Curses::Toolkit::Widget
   output : a Curses::Toolkit::Theme::Default::Color object
 
-
-
 =head1 AUTHOR
 
-  Damien "dams" Krotkine
+Damien "dams" Krotkine
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2008 by Damien "dams" Krotkine.
+This software is copyright (c) 2010 by Damien "dams" Krotkine.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
\ No newline at end of file
+=cut
+
