@@ -1,18 +1,18 @@
-# 
+#
 # This file is part of Curses-Toolkit
-# 
-# This software is copyright (c) 2008 by Damien "dams" Krotkine.
-# 
+#
+# This software is copyright (c) 2010 by Damien "dams" Krotkine.
+#
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
-# 
+#
 use warnings;
 use strict;
 
 package Curses::Toolkit::Widget::HPaned;
-our $VERSION = '0.100680';
-
-
+BEGIN {
+  $Curses::Toolkit::Widget::HPaned::VERSION = '0.200';
+}
 
 # ABSTRACT: a container with two panes arranged horizontally
 
@@ -24,12 +24,12 @@ use Params::Validate qw(:all);
 
 sub _p1 {
     my ( $self, $c ) = @_;
-    return $c->x1();
+    return $c->get_x1();
 }
 
 sub _p2 {
     my ( $self, $c ) = @_;
-    return $c->y2();
+    return $c->get_y2();
 }
 
 sub _p3 {
@@ -39,12 +39,12 @@ sub _p3 {
 
 sub _p4 {
     my ( $self, $c, $gp ) = @_;
-    return ( x2 => $c->x1() + $gp );
+    return ( x2 => $c->get_x1() + $gp );
 }
 
 sub _p5 {
     my ( $self, $c, $gp, $gw ) = @_;
-    return ( x1 => $c->x1() + $gp + $gw );
+    return ( x1 => $c->get_x1() + $gp + $gw );
 }
 
 sub _p6 {
@@ -54,46 +54,45 @@ sub _p6 {
 
 sub _p7 {
     my ( $self, $theme, $c, $i, $gp, $attr ) = @_;
-    $theme->draw_vline( $c->x1() + $gp + $i, $c->y1(), $c->height(), $attr );
+    $theme->draw_vline( $c->get_x1() + $gp + $i, $c->get_y1(), $c->height(), $attr );
     return;
 }
 
 sub _p8 {
     my ( $self, $c, $gp, $gw ) = @_;
-    return ( x2 => $c->x1() + $gp + $gw );
+    return ( x2 => $c->get_x1() + $gp + $gw );
 }
 
 sub _p9 {
     my ( $self, $c ) = @_;
-    return ( y2 => $c->y2() );
+    return ( y2 => $c->get_y2() );
 }
 
 sub _p10 {
     my ( $self, $c ) = @_;
-    return ( x1 => $c->x1() );
+    return ( x1 => $c->get_x1() );
 }
 
 sub _p11 {
     my ( $self, $c1, $c2 ) = @_;
-    return ( x2 => $c1->x1() + $c1->width() + $c2->width() );
+    return ( x2 => $c1->get_x1() + $c1->width() + $c2->width() );
 }
 
 sub _p12 {
     my ( $self, $c ) = @_;
-    return ( y2 => $c->y1() + 1 );
+    return ( y2 => $c->get_y1() + 1 );
 }
 
 sub _p13 {
     my ( $self, $c1, $c2 ) = @_;
     use List::Util qw(max);
-    return ( y2 => max( $c1->y2(), $c2->y2() ) );
+    return ( y2 => max( $c1->get_y2(), $c2->get_y2() ) );
 }
 
 
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -102,7 +101,11 @@ Curses::Toolkit::Widget::HPaned - a container with two panes arranged horizontal
 
 =head1 VERSION
 
-version 0.100680
+version 0.200
+
+=head1 DESCRIPTION
+
+This widget contain 2 widgets. The children are packed horizontally.
 
 =head1 Appearence
 
@@ -118,12 +121,6 @@ With a border
   |                 |
   +-----------------+
 
-=head1 DESCRIPTION
-
-This widget contain 2 widgets. The children are packed horizontally.
-
-
-
 =head1 CONSTRUCTOR
 
 =head2 new
@@ -131,8 +128,6 @@ This widget contain 2 widgets. The children are packed horizontally.
   input : none
   output : a Curses::Toolkit::Widget::HPaned
 
-
-
 =head1 METHODS
 
 =head2 add1
@@ -178,17 +173,16 @@ needed to properly display itself
   input : a Curses::Toolkit::Object::Coordinates object
   output : a Curses::Toolkit::Object::Coordinates object
 
-
-
 =head1 AUTHOR
 
-  Damien "dams" Krotkine
+Damien "dams" Krotkine
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2008 by Damien "dams" Krotkine.
+This software is copyright (c) 2010 by Damien "dams" Krotkine.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
\ No newline at end of file
+=cut
+
