@@ -1,18 +1,18 @@
-# 
+#
 # This file is part of Curses-Toolkit
-# 
-# This software is copyright (c) 2008 by Damien "dams" Krotkine.
-# 
+#
+# This software is copyright (c) 2010 by Damien "dams" Krotkine.
+#
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
-# 
+#
 use warnings;
 use strict;
 
 package Curses::Toolkit::Widget::VBox;
-our $VERSION = '0.100680';
-
-
+BEGIN {
+  $Curses::Toolkit::Widget::VBox::VERSION = '0.200';
+}
 
 # ABSTRACT: a vertical box widget
 
@@ -93,7 +93,7 @@ sub _rebuild_children_coordinates {
             my $space = $child->get_minimum_space($remaining_space);
             my $h     = $space->height();
             $height += $h;
-            $remaining_space->substract( { y2 => $h } );
+            $remaining_space->subtract( { y2 => $h } );
             $children_heights[$idx] = $h;
             $idx++;
         }
@@ -109,10 +109,10 @@ sub _rebuild_children_coordinates {
         } else {
             my $avg_height = int( $remaining_space->height() / $count );
             my $avg_space  = $remaining_space->clone();
-            $avg_space->set( y2 => $avg_space->y1() + $avg_height );
+            $avg_space->set( y2 => $avg_space->get_y1() + $avg_height );
             my $space = $child->get_desired_space($avg_space);
             my $h     = $space->height();
-            $remaining_space->substract( { y2 => $h } );
+            $remaining_space->subtract( { y2 => $h } );
             $height += $h;
             $children_heights[$idx] = $h;
             $count--;
@@ -153,7 +153,7 @@ sub get_desired_space {
         my $space = $child->get_minimum_space($remaining_space);
         my $h     = $space->height();
         $height += $h;
-        $remaining_space->substract( { y2 => $h } );
+        $remaining_space->subtract( { y2 => $h } );
     }
 
     # add to it the height of the expanding children, restricted
@@ -163,15 +163,15 @@ sub get_desired_space {
     foreach my $child (@expanding_children) {
         my $avg_height = int( $remaining_space->height() / $count );
         my $avg_space  = $remaining_space->clone();
-        $avg_space->set( y2 => $avg_space->y1() + $avg_height );
+        $avg_space->set( y2 => $avg_space->get_y1() + $avg_height );
         my $space = $child->get_desired_space($avg_space);
         my $h     = $space->height();
-        $remaining_space->substract( { y2 => $h } );
+        $remaining_space->subtract( { y2 => $h } );
         $height += $h;
         $count--;
     }
 
-    $desired_space->set( y2 => $desired_space->y1() + $height );
+    $desired_space->set( y2 => $desired_space->get_y1() + $height );
 
     return $desired_space;
 
@@ -194,12 +194,12 @@ sub get_minimum_space {
         $height += $h;
         use List::Util qw(max);
         $width = max $width, $space->width();
-        $remaining_space->substract( { y2 => $h } );
+        $remaining_space->subtract( { y2 => $h } );
     }
 
     $minimum_space->set(
-        y2 => $minimum_space->y1() + $height,
-        x2 => $minimum_space->x1() + $width,
+        y2 => $minimum_space->get_y1() + $height,
+        x2 => $minimum_space->get_x1() + $width,
     );
 
     return $minimum_space;
@@ -209,7 +209,6 @@ sub get_minimum_space {
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -218,14 +217,12 @@ Curses::Toolkit::Widget::VBox - a vertical box widget
 
 =head1 VERSION
 
-version 0.100680
+version 0.200
 
 =head1 DESCRIPTION
 
 This widget can contain 0 or more widgets. The children are packed vertically.
 
-
-
 =head1 CONSTRUCTOR
 
 =head2 new
@@ -233,8 +230,6 @@ This widget can contain 0 or more widgets. The children are packed vertically.
   input : none
   output : a Curses::Toolkit::Widget::VBox
 
-
-
 =head1 METHODS
 
 =head2 pack_start
@@ -263,8 +258,6 @@ over and above the global amount specified by "spacing" property. If child is
 a widget at one of the reference ends of box, then padding pixels are also
 put between child and the reference edge of box
 
-
-
 =head2 get_desired_space
 
 Given a coordinate representing the available space, returns the space desired
@@ -272,8 +265,6 @@ Given a coordinate representing the available space, returns the space desired
   input : a Curses::Toolkit::Object::Coordinates object
   output : a Curses::Toolkit::Object::Coordinates object
 
-
-
 =head2 get_minimum_space
 
 Given a coordinate representing the available space, returns the minimum space
@@ -282,17 +273,16 @@ needed to properly display itself
   input : a Curses::Toolkit::Object::Coordinates object
   output : a Curses::Toolkit::Object::Coordinates object
 
-
-
 =head1 AUTHOR
 
-  Damien "dams" Krotkine
+Damien "dams" Krotkine
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2008 by Damien "dams" Krotkine.
+This software is copyright (c) 2010 by Damien "dams" Krotkine.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
\ No newline at end of file
+=cut
+
