@@ -1,18 +1,18 @@
-# 
+#
 # This file is part of Curses-Toolkit
-# 
-# This software is copyright (c) 2008 by Damien "dams" Krotkine.
-# 
+#
+# This software is copyright (c) 2010 by Damien "dams" Krotkine.
+#
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
-# 
+#
 use warnings;
 use strict;
 
 package Curses::Toolkit::Widget::VPaned;
-our $VERSION = '0.100680';
-
-
+BEGIN {
+  $Curses::Toolkit::Widget::VPaned::VERSION = '0.200';
+}
 
 # ABSTRACT: a container with two panes arranged horizontally
 use parent qw(Curses::Toolkit::Widget::Paned);
@@ -23,12 +23,12 @@ use Params::Validate qw(:all);
 
 sub _p1 {
     my ( $self, $c ) = @_;
-    return $c->y1();
+    return $c->get_y1();
 }
 
 sub _p2 {
     my ( $self, $c ) = @_;
-    return $c->x2();
+    return $c->get_x2();
 }
 
 sub _p3 {
@@ -38,12 +38,12 @@ sub _p3 {
 
 sub _p4 {
     my ( $self, $c, $gp ) = @_;
-    return ( y2 => $c->y1() + $gp );
+    return ( y2 => $c->get_y1() + $gp );
 }
 
 sub _p5 {
     my ( $self, $c, $gp, $gw ) = @_;
-    return ( y1 => $c->y1() + $gp + $gw );
+    return ( y1 => $c->get_y1() + $gp + $gw );
 }
 
 sub _p6 {
@@ -53,46 +53,45 @@ sub _p6 {
 
 sub _p7 {
     my ( $self, $theme, $c, $i, $gp, $attr ) = @_;
-    $theme->draw_hline( $c->x1(), $c->y1() + $gp + $i, $c->width(), $attr );
+    $theme->draw_hline( $c->get_x1(), $c->get_y1() + $gp + $i, $c->width(), $attr );
     return;
 }
 
 sub _p8 {
     my ( $self, $c, $gp, $gw ) = @_;
-    return ( y2 => $c->y1() + $gp + $gw );
+    return ( y2 => $c->get_y1() + $gp + $gw );
 }
 
 sub _p9 {
     my ( $self, $c ) = @_;
-    return ( x2 => $c->x2() );
+    return ( x2 => $c->get_x2() );
 }
 
 sub _p10 {
     my ( $self, $c ) = @_;
-    return ( y1 => $c->y1() );
+    return ( y1 => $c->get_y1() );
 }
 
 sub _p11 {
     my ( $self, $c1, $c2 ) = @_;
-    return ( y2 => $c1->y1() + $c1->height() + $c2->height() );
+    return ( y2 => $c1->get_y1() + $c1->height() + $c2->height() );
 }
 
 sub _p12 {
     my ( $self, $c ) = @_;
-    return ( x2 => $c->x1() + 1 );
+    return ( x2 => $c->get_x1() + 1 );
 }
 
 sub _p13 {
     my ( $self, $c1, $c2 ) = @_;
     use List::Util qw(max);
-    return ( x2 => max( $c1->x2(), $c2->x2() ) );
+    return ( x2 => max( $c1->get_x2(), $c2->get_x2() ) );
 }
 
 
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -101,7 +100,11 @@ Curses::Toolkit::Widget::VPaned - a container with two panes arranged horizontal
 
 =head1 VERSION
 
-version 0.100680
+version 0.200
+
+=head1 DESCRIPTION
+
+This widget contain 2 widgets. The children are packed horizontally.
 
 =head1 Appearence
 
@@ -114,12 +117,6 @@ With a border
   |          |           |
   +----------+-----------+
 
-=head1 DESCRIPTION
-
-This widget contain 2 widgets. The children are packed horizontally.
-
-
-
 =head1 CONSTRUCTOR
 
 =head2 new
@@ -127,8 +124,6 @@ This widget contain 2 widgets. The children are packed horizontally.
   input : none
   output : a Curses::Toolkit::Widget::VPaned
 
-
-
 =head1 METHODS
 
 =head2 add1
@@ -174,17 +169,16 @@ needed to properly display itself
   input : a Curses::Toolkit::Object::Coordinates object
   output : a Curses::Toolkit::Object::Coordinates object
 
-
-
 =head1 AUTHOR
 
-  Damien "dams" Krotkine
+Damien "dams" Krotkine
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2008 by Damien "dams" Krotkine.
+This software is copyright (c) 2010 by Damien "dams" Krotkine.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
\ No newline at end of file
+=cut
+
