@@ -1,18 +1,18 @@
-# 
+#
 # This file is part of Curses-Toolkit
-# 
-# This software is copyright (c) 2008 by Damien "dams" Krotkine.
-# 
+#
+# This software is copyright (c) 2010 by Damien "dams" Krotkine.
+#
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
-# 
+#
 use strict;
 use warnings;
 
 package Curses::Toolkit::Widget::VProgressBar;
-our $VERSION = '0.100680';
-
-
+BEGIN {
+  $Curses::Toolkit::Widget::VProgressBar::VERSION = '0.200';
+}
 
 # ABSTRACT: a vertical progress bar widget
 
@@ -44,10 +44,10 @@ sub draw {
 
     my $char_done    = $self->get_theme_property('char_done');
     my $char_left    = $self->get_theme_property('char_left');
-    my $upper_string  = $self->get_theme_property('upper_enclosing');
-    my $bottom_string = $self->get_theme_property('bottom_enclosing');
-    my $wl           = length $upper_string;
-    my $wr           = length $bottom_string;
+    my $upper_string  = $self->get_theme_property('start_enclosing');
+    my $bottom_string = $self->get_theme_property('end_enclosing');
+    my $hu           = length $upper_string;
+    my $hb           = length $bottom_string;
     my $bw           = $self->get_theme_property('border_width');
 
 
@@ -60,32 +60,37 @@ sub draw {
         $text = "$value";
     }
 
-    # <------------ w1 ---------------->
-    #  <------------ w2 -------------->
-    #  <-$w_done-><-     $w_left     ->
-    # [|||||||||||----34%--------------]
-    # -^  o1
-    # ----- o2 ---^
-    # --------- o3 ---^
-    # ---------------- o4 -------------^
 
-    my $w1     = $c->width() - 2 * $bw;
-    my $w2     = $w1 - $wl - $wr;
-    my $w_done = int( $w2 * ( $pos - $min ) / ( $max - $min ) );
-    my $w_left = $w2 - $w_done;
+    # 
+    #    ^               _ 
+    #    |     ^      ^  # < o1
+    #    |     |   hd |  #
+    #    |     |      \/ #
+    #  h1|   h2|      ^  | < o2
+    #    |     |      |  |
+    #    |     |   hl |  |
+    #    |     |      |  |
+    #    |     \/     \/ |
+    #    \/              - < o4
+    #
 
-    my $o1 = $wl;
-    my $o2 = $o1 + $w_done;
-    my $o3 = ( $w1 - length $text ) / 2;
-    my $o4 = $w1 - $wr;
+    my $h1     = $c->height() - 2 * $bw;
+    my $h2     = $h1 - $hu - $hb;
+    my $h_done = int( $h2 * ( $pos - $min ) / ( $max - $min ) );
+    my $h_left = $h2 - $h_done;
 
-    $theme->draw_string( $c->x1() + $bw,       $c->y1() + $bw, $upper_string );
-    $theme->draw_string( $c->x1() + $bw + $o4, $c->y1() + $bw, $bottom_string );
+    my $o1 = $hu;
+    my $o2 = $o1 + $h_done;
+ #   my $o3 = ( $h1 - length $text ) / 2;
+    my $o4 = $h1 - $hb;
 
-    $theme->draw_string( $c->x1() + $bw + $o1, $c->y1() + $bw, $char_done x $w_done );
-    $theme->draw_string( $c->x1() + $bw + $o2, $c->y1() + $bw, $char_left x $w_left );
+    $theme->draw_vstring( $c->get_x1() + $bw, $c->get_y1() + $bw, $upper_string );
+    $theme->draw_vstring( $c->get_x1() + $bw, $c->get_y1() + $bw + $o4, $bottom_string );
 
-    $theme->draw_string( $c->x1() + $bw + $o3, $c->y1() + $bw, $text );
+    $theme->draw_vstring( $c->get_x1() + $bw, $c->get_y1() + $bw + $o1, $char_done x $h_done );
+    $theme->draw_vstring( $c->get_x1() + $bw, $c->get_y1() + $bw + $o2, $char_left x $h_left );
+
+#    $theme->draw_vstring( $c->get_x1() + $bw, $c->get_y1() + $bw + $o3, $text );
 
     return;
 }
@@ -94,7 +99,7 @@ sub draw {
 sub get_desired_space {
     my ( $self, $available_space ) = @_;
     my $desired_space = $available_space->clone;
-    $desired_space->set( y2 => $desired_space->y1 + 1 );
+    $desired_space->set( y2 => $desired_space->get_y1 + 1 );
     $desired_space->grow_to($self->get_minimum_space($available_space));
     return $desired_space;
 }
@@ -104,13 +109,13 @@ sub get_minimum_space {
     my ( $self, $available_space ) = @_;
 
     my $minimum_space = $available_space->clone;
-    my $default_width = $self->get_theme_property('default_width');
+    my $default_height = $self->get_theme_property('default_length');
     my $bw            = $self->get_theme_property('border_width');
-    my $upper_string   = $self->get_theme_property('upper_enclosing');
-    my $bottom_string  = $self->get_theme_property('bottom_enclosing');
+    my $upper_string  = $self->get_theme_property('start_enclosing');
+    my $bottom_string = $self->get_theme_property('end_enclosing');
     $minimum_space->set(
-        x2 => $available_space->x1() + 2 * $bw + length($upper_string) + $default_width + length($bottom_string),
-        y2 => $available_space->y1() + 1 + 2 * $bw,
+        x2 => $available_space->get_y1() + 1 + 2 * $bw,
+        y2 => $available_space->get_x1() + 2 * $bw + length($upper_string) + $default_height + length($bottom_string),
     );
     return $minimum_space;
 }
@@ -118,22 +123,13 @@ sub get_minimum_space {
 
 
 
-sub _get_theme_properties_definition {
-    my ($self) = @_;
-    return {
-        %{ $self->SUPER::_get_theme_properties_definition() },
-        default_width   => { optional => 0, type => SCALAR, },
-        upper_enclosing  => { optional => 0, type => SCALAR, },
-        bottom_enclosing => { optional => 0, type => SCALAR, },
-
-    };
-}
+no Moose;
+__PACKAGE__->meta->make_immutable (inline_constructor => 0);
 
 1;
 
 
 
-
 =pod
 
 =head1 NAME
@@ -142,91 +138,16 @@ Curses::Toolkit::Widget::VProgressBar - a vertical progress bar widget
 
 =head1 VERSION
 
-version 0.100680
-
-=head1 THEME RELATED PROPERTIES
-
-To set/get a theme properties, you should do :
-
-  $vprogress_bar->set_theme_property(property_name => $property_value);
-  $value = $button->get_theme_property('property_name');
-
-Here is the list of properties related to the progressbar, that can be
-changed in the associated theme. See the L<Curses::Toolkit::Theme> class
-used for the default (default class to look at is
-L<Curses::Toolkit::Theme::Default>)
-
-Don't forget to look at properties from the parent class, as these are also
-inherited from!
-
-=head2 border_width (inherited)
-
-The width of the border of the progress bar.
-
-Example:
-  # set buttons to have a border of 1
-  $vprogressbar->set_theme_property(border_width => 1 );
-
-=head2 default_width
-
-Sets the value of the default width of the progress bar.
-
-=head2 char_done
-
-Sets the value of the char used to represent the done portion of the
-progress bar.
-
-Example :
-  # set char_done
-  $vprogressbar->set_theme_property(char_done => '=' );
-
-=head2 char_left
-
-Sets the value of the char used to represent the left portion of the
-progress bar.
-
-Example :
-  # set char_left
-  $vprogressbar->set_theme_property(char_left => '=' );
-
-=head2 upper_enclosing
-
-The string to be displayed at the upper of the progress bar. Usually some enclosing characters.
-
-Example :
-  # set upper enclosing
-  $vprogressbar->set_theme_property(upper_enclosing => '< ' );
-  $vprogressbar->set_theme_property(upper_enclosing => '[ ' );
-
-=head2 bottom_enclosing
-
-The string to be displayed at the bottom of the progress bar. Usually some enclosing characters.
-
-Example :
-  # set bottom enclosing
-  $vprogressbar->set_theme_property(bottom_enclosing => ' >' );
-  $vprogressbar->set_theme_property(bottom_enclosing => ' ]' );
-
-
-
-=head1 Appearence
-
-Standard theme:
-
-  ||||||||---------- 14% ------------------
-
-With a border:
-
-  +------------------------------------------+
-  |||||||||---------- 14% -------------------|
-  +------------------------------------------+
+version 0.200
 
 =head1 DESCRIPTION
 
-The C<Curses::Toolkit::Widget::ProgressBar> widget is a classical
+The C<Curses::Toolkit::Widget::VProgressBar> widget is a classical
 progress bar widget, used to provide some sort of progress information
 to your program user.
 
+This Progress bar is vertical.
+
 =head1 ATTRIBUTES
 
 =head2 minimum
@@ -247,8 +168,6 @@ What to show in the progress bar. Must be a C<PROGRESS_BAR_LABEL> -
 check L<Curses::Toolkit::Types> for valid options. Default to
 C<percent>.
 
-
-
 =head1 METHODS
 
 =head2 new
@@ -256,14 +175,10 @@ C<percent>.
   input:  none
   output: a Curses::Toolkit::Widget::VProgressBar
 
-
-
 =head2 draw
 
 Redraw the progress bar.
 
-
-
 =head2 get_desired_space
 
 Given a coordinate representing the available space, returns the space desired
@@ -274,8 +189,6 @@ The Button desires the minimum size : text length plus the button brackets
 
 The desired space is as much horizontal space as possible, with a height of 1.
 
-
-
 =head2 get_minimum_space
 
 Given a coordinate representing the available space, returns the
@@ -287,11 +200,9 @@ button brackets.
 
 The ProgressBar requires 12x1 minimum.
 
-
-
 =head2 possible_signals
 
-  my @signals = keys $button->possible_signals();
+  my @signals = keys $vprogressbar->possible_signals();
 
 Returns the possible signals that can be used on this widget. See
 L<Curses::Toolkit::Widget::signal_connect> to bind signals to actions
@@ -301,21 +212,99 @@ L<Curses::Toolkit::Widget::signal_connect> to bind signals to actions
 
 The progress bar accepts no signal.
 
+=head1 THEME RELATED PROPERTIES
 
+To set/get a theme properties, you should do :
+
+  $vprogressbar->set_theme_property(property_name => $property_value);
+  $value = $vprogressbar->get_theme_property('property_name');
+
+Here is the list of properties related to the progressbar, that can be
+changed in the associated theme. See the L<Curses::Toolkit::Theme> class
+used for the default (default class to look at is
+L<Curses::Toolkit::Theme::Default>)
+
+Don't forget to look at properties from the parent class, as these are also
+inherited from!
+
+=head2 border_width (inherited)
+
+The width of the border of the progressbar.
+
+Example:
+  # set the progressbar to have a border of 1
+  $vprogressbar->set_theme_property(border_width => 1 );
+
+=head2 default_length
+
+Sets the value of the default length of the progress bar.
+
+Example :
+  # set default_length
+  $vprogressbar->set_theme_property(default_length => 10 );
+
+=head2 char_done
+
+Sets the value of the char used to represent the done portion of the
+progress bar.
+
+Example :
+  # set char_done
+  $vprogressbar->set_theme_property(char_done => '=' );
+
+=head2 char_left
+
+Sets the value of the char used to represent the left portion of the
+progress bar.
+
+Example :
+  # set char_left
+  $vprogressbar->set_theme_property(char_left => ' ' );
+
+=head2 start_enclosing
+
+The string to be displayed at the top of the progress bar. Usually some enclosing characters.
+
+Example :
+  # set top enclosing
+  $vprogressbar->set_theme_property(start_enclosing => '< ' );
+  $vprogressbar->set_theme_property(start_enclosing => '[ ' );
+
+=head2 end_enclosing
+
+The string to be displayed at the bottom of the progress bar. Usually some enclosing characters.
+
+Example :
+  # set bottom enclosing
+  $vprogressbar->set_theme_property(end_enclosing => ' >' );
+  $vprogressbar->set_theme_property(end_enclosing => ' ]' );
+
+=head1 Appearence
+
+Standard theme:
+
+  ||||||||---------- 14% ------------------
+
+With a border:
+
+  +------------------------------------------+
+  |||||||||---------- 14% -------------------|
+  +------------------------------------------+
 
 =head1 AUTHOR
 
-  Damien "dams" Krotkine
+Damien "dams" Krotkine
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2008 by Damien "dams" Krotkine.
+This software is copyright (c) 2010 by Damien "dams" Krotkine.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
+=cut
 
 
+__END__
+
 
-__END__
\ No newline at end of file
